# noice

noice is a collection of [noice](https://www.merriam-webster.com/words-at-play/what-does-noice-mean) data tools for noice [data people](https://www.reddit.com/r/dataengineering/comments/nc6ptk/tell_us_youre_a_data_engineer_without_telling_us/).

![noice](https://media.giphy.com/media/4KF85OSbyjVOfyjksJ/giphy.gif)

## pypi

[noice](https://pypi.org/project/noice/)

---
Made with ❤️ by the team at [Mashey](http://mashey.com)
